==> eam-wshub-proxyclient-11.6-0-sources.jar: net/datastream/schemas/mp_fields/CAMPAIGNEVENTID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour CAMPAIGNEVENTID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="CAMPAIGNEVENTID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CAMPAIGNID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CAMPAIGNEVENT"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CAMPAIGNEVENTID_Type", propOrder = {
    "campaignid",
    "campaignevent"
})
public class CAMPAIGNEVENTID_Type {

    @XmlElement(name = "CAMPAIGNID", required = true)
    protected CAMPAIGNID_Type campaignid;
    @XmlElement(name = "CAMPAIGNEVENT")
    protected long campaignevent;

    /**
     * Obtient la valeur de la propriété campaignid.
     * 
     * @return
     *     possible object is
     *     {@link CAMPAIGNID_Type }
     *     
     */
    public CAMPAIGNID_Type getCAMPAIGNID() {
        return campaignid;
    }

    /**
     * Définit la valeur de la propriété campaignid.
     * 
     * @param value
     *     allowed object is
     *     {@link CAMPAIGNID_Type }
     *     
     */
    public void setCAMPAIGNID(CAMPAIGNID_Type value) {
        this.campaignid = value;
    }

    /**
     * Obtient la valeur de la propriété campaignevent.
     * 
     */
    public long getCAMPAIGNEVENT() {
        return campaignevent;
    }

    /**
     * Définit la valeur de la propriété campaignevent.
     * 
     */
    public void setCAMPAIGNEVENT(long value) {
        this.campaignevent = value;
    }

}

==> eam-wshub-proxyclient-12.1-0-sources.jar: net/datastream/schemas/mp_fields/CAMPAIGNEVENTID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for CAMPAIGNEVENTID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="CAMPAIGNEVENTID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CAMPAIGNID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CAMPAIGNEVENT"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CAMPAIGNEVENTID_Type", propOrder = {
    "campaignid",
    "campaignevent"
})
public class CAMPAIGNEVENTID_Type {

    @XmlElement(name = "CAMPAIGNID", required = true)
    protected CAMPAIGNID_Type campaignid;
    @XmlElement(name = "CAMPAIGNEVENT")
    protected long campaignevent;

    /**
     * Gets the value of the campaignid property.
     * 
     * @return
     *     possible object is
     *     {@link CAMPAIGNID_Type }
     *     
     */
    public CAMPAIGNID_Type getCAMPAIGNID() {
        return campaignid;
    }

    /**
     * Sets the value of the campaignid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CAMPAIGNID_Type }
     *     
     */
    public void setCAMPAIGNID(CAMPAIGNID_Type value) {
        this.campaignid = value;
    }

    /**
     * Gets the value of the campaignevent property.
     * 
     */
    public long getCAMPAIGNEVENT() {
        return campaignevent;
    }

    /**
     * Sets the value of the campaignevent property.
     * 
     */
    public void setCAMPAIGNEVENT(long value) {
        this.campaignevent = value;
    }

}
